@@ -9,6 +9,9 @@
 #' @param expr,with an expression
 #' @param topEncl (environment) the root of the local search path. It is tried
 #'   to find a good default via \link{autoTopEncl}.
+#' @param envir (environment) the environment from where \code{module} is
+#'   called. Used to determine the top level environment and should not be
+#'   supplied by the use.
 #' @param from (character, or unquoted expression) a package name
 #' @param ... (character, or unquoted expression) names to import from package
 #'   or names to export from module. For exports a character of length 1 with a
@@ -47,9 +50,11 @@
 #' \emph{exposed} functions can be (re-)exported.
 #'
 #' \code{extend} can be used to extend an existing module definition. This
-#' feature is meant to be used by a module author to split a module definition
-#' into different files. You can also refer to a folder name in \code{use} which
-#' is interpreted to use all files as sub-modules.
+#'   feature is meant to be used by a module author. This can be very useful to
+#'   write unit tests when they need to have access to private member functions
+#'   of the module. It is not safe as a consumer or user of a module to use this
+#'   feature as it breaks encapsulation. When you are looking for mechanisms for
+#'   reuse, \code{expose} and \code{use} should be favoured.
 #'
 #' @examples
 #' \dontrun{
@@ -80,8 +85,8 @@
 #'
 #' @rdname module
 #' @export
-module <- function(expr = {}, topEncl = autoTopEncl(parent.frame())) {
-  ModuleConst(match.call()$expr, topEncl)
+module <- function(expr = {}, topEncl = autoTopEncl(envir), envir = parent.frame()) {
+  ModuleConst(match.call()$expr, topEncl, topenv(envir))
 }
 
 #' @export
@@ -90,7 +95,7 @@ print.module <- function(x, ...) {
   getFormals <- function(fun) {
     formalsOfFun <- formals(fun)
     formalsOfFun[sapply(formalsOfFun, is.character)] <-
-      lapply(formalsOfFun[sapply(formalsOfFun, is.character)], function(el){
+      lapply(formalsOfFun[sapply(formalsOfFun, is.character)], function(el) {
         paste0("\"", el, "\"")
       })
     args <- ifelse(
